package Bio::EnsEMBL::Funcgen::Hive::Ftp::WriteReadmeFile;

use strict;
use Data::Dumper;
use base ('Bio::EnsEMBL::Hive::Process');

sub run {
  my $self    = shift;
  my $destination = $self->param('destination');
  
  use File::Basename;
  my $destination_dir = dirname($destination);

  use File::Path qw(make_path);
  make_path($destination_dir);

  use IO::File;
  my $output_fh = IO::File->new(">$destination");
  
  my $readme_content = $self->generate_readme_content();

  $output_fh->print($readme_content);
}

sub generate_readme_content {

  my $self = shift;
  
  return <<README_FILE_CONTENT
#### README ####

-----------------------
GFF FLATFILE DUMPS
-----------------------
This directory contains GFF flatfile dumps. All files are compressed using 
GNU Zip.

Annotated Features
------------------
Annotated features in Ensembl Regulation are the result of peak calling 
analyses.

All annotated features are exported to the file AnnotatedFeatures.gff.gz. The 
start and end coordinates of every annotated feature are the region which has 
been identified as enriched by the peak caller. The coordinate of the summit 
is given in the description.

More details on the peak callers used are here: 
http://www.ensembl.org/info/genome/funcgen/regulation_sources.html

Motif features
--------------
The results of the motif searches are exported to MotifFeatures.gff.gz.

They are generated by searching for motif patterns. The motifs are defined by 
Positional Weight Matrices (PWMs). Matches from PWMs are only stored in the 
database, if they are in one of the enriched regions. 

The PWMs used were from Jaspar:
http://jaspar.genereg.net

See
http://www.ensembl.org/info/genome/funcgen/regulatory_build.html#tfbs
for more details on how Ensembl Regulation searches for motifs.

Regulatory features
-------------------

For every epigenome the regulatory features are exported with their 
predicted activity in that epigenome. This leads to one file per epigenome. 
The files are in the subdirectory regulatory_features.

More information on how the regulatory build is created is available here: 
http://www.ensembl.org/info/genome/funcgen/regulatory_build.html
README_FILE_CONTENT

}

1;
